@@ -1,4 +1,4 @@
-# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2016 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -44,7 +44,7 @@ from lib import xml
 
 from lib.check.msgformat import c as msgformat_c
 from lib.check.msgformat import python as msgformat_python
-from lib.check.repr import message_repr
+from lib.check.msgrepr import message_repr
 
 class EnvironmentNotPatched(RuntimeError):
     pass
@@ -180,6 +180,7 @@ class Checker(object, metaclass=abc.ABCMeta):
         ctx = misc.Namespace()
         ctx.file = file
         ctx.is_template = is_template
+        self.check_comments(ctx)
         self.check_headers(ctx)
         self.check_language(ctx)
         self.check_plurals(ctx)
@@ -191,6 +192,25 @@ class Checker(object, metaclass=abc.ABCMeta):
         self.check_translator(ctx)
         self.check_messages(ctx)
 
+    def check_comments(self, ctx):
+        regexs = {
+            r'\bPACKAGE package\b',
+            r'\bCopyright \S+ YEAR\b',
+            r"\bTHE PACKAGE'S COPYRIGHT HOLDER\b",
+        }
+        if not ctx.is_template:
+            regexs |= {
+                r'\bFIRST AUTHOR\b',
+                r'<EMAIL@ADDRESS>',
+                r'(?<=>), YEAR\b',
+            }
+        regex = re.compile('|'.join(regexs))
+        for line in ctx.file.header.splitlines():
+            match =  regex.search(line)
+            if match is None:
+                continue
+            self.tag('boilerplate-in-initial-comments', line)
+
     @checks_header_fields('Language', 'X-Poedit-Language', 'X-Poedit-Country')
     def check_language(self, ctx):
         ctx.language = None
@@ -380,81 +400,100 @@ class Checker(object, metaclass=abc.ABCMeta):
         if ctx.is_template:
             return
         try:
-            (n, expr) = gettext.parse_plural_forms(plural_forms)
+            (n, expr, ljunk, rjunk) = gettext.parse_plural_forms(plural_forms, strict=False)
         except gettext.PluralFormsSyntaxError:
             if has_plurals:
                 self.tag('syntax-error-in-plural-forms', plural_forms, '=>', plural_forms_hint)
             else:
                 self.tag('syntax-error-in-unused-plural-forms', plural_forms, '=>', plural_forms_hint)
-        else:
-            if len(expected_nplurals) == 1:
-                [expected_nplurals] = expected_nplurals.keys()
-                if n != expected_nplurals:
-                    self.tag('incorrect-number-of-plural-forms',
-                        n, tags.safestr('(Plural-Forms header field)'), '!=',
-                        expected_nplurals, tags.safestr('(number of msgstr items)')
-                    )
-            locally_correct_n = locally_correct_expr = None
-            if correct_plural_forms is not None:
-                locally_correct_plural_forms = [
-                    (i, expression)
-                    for i, expression in map(gettext.parse_plural_forms, correct_plural_forms)
-                    if i == n
-                ]
-                if not locally_correct_plural_forms:
-                    if has_plurals:
-                        self.tag('incorrect-plural-forms', plural_forms, '=>', plural_forms_hint)
-                    else:
-                        self.tag('incorrect-unused-plural-forms', plural_forms, '=>', plural_forms_hint)
-                elif len(locally_correct_plural_forms) == 1:
-                    [[locally_correct_n, locally_correct_expr]] = locally_correct_plural_forms
-            plural_preimage = collections.defaultdict(list)
-            try:
-                for i in range(200):
-                    fi = expr(i)
-                    if fi >= n:
-                        message = tags.safe_format('f({}) = {} >= {}'.format(i, fi, n))
-                        if has_plurals:
-                            self.tag('codomain-error-in-plural-forms', message)
-                        else:
-                            self.tag('codomain-error-in-unused-plural-forms', message)
-                        break
-                    plural_preimage[fi] += [i]
-                    if n == locally_correct_n and fi != locally_correct_expr(i):
-                        if has_plurals:
-                            self.tag('incorrect-plural-forms', plural_forms, '=>', plural_forms_hint)
-                        else:
-                            self.tag('incorrect-unused-plural-forms', plural_forms, '=>', plural_forms_hint)
-                        break
-                else:
-                    ctx.plural_preimage = dict(plural_preimage)
-            except OverflowError:
-                message = tags.safe_format('f({}): integer overflow', i)
+            return
+        if ljunk:
+            self.tag('leading-junk-in-plural-forms', ljunk)
+        if rjunk:
+            self.tag('trailing-junk-in-plural-forms', rjunk)
+        if len(expected_nplurals) == 1:
+            [expected_nplurals] = expected_nplurals.keys()
+            if n != expected_nplurals:
+                self.tag('incorrect-number-of-plural-forms',
+                    n, tags.safestr('(Plural-Forms header field)'), '!=',
+                    expected_nplurals, tags.safestr('(number of msgstr items)')
+                )
+        locally_correct_n = locally_correct_expr = None
+        if correct_plural_forms is not None:
+            locally_correct_plural_forms = [
+                (i, expression)
+                for i, expression in map(gettext.parse_plural_forms, correct_plural_forms)
+                if i == n
+            ]
+            if not locally_correct_plural_forms:
                 if has_plurals:
-                    self.tag('arithmetic-error-in-plural-forms', message)
+                    self.tag('unusual-plural-forms', plural_forms, '=>', plural_forms_hint)
                 else:
-                    self.tag('arithmetic-error-in-unused-plural-forms', message)
-            except ZeroDivisionError:
-                message = tags.safe_format('f({}): division by zero', i)
-                if has_plurals:
-                    self.tag('arithmetic-error-in-plural-forms', message)
-                else:
-                    self.tag('arithmetic-error-in-unused-plural-forms', message)
-            codomain = expr.codomain()
-            if codomain is not None:
-                (x, y) = codomain
-                rngs = []
-                if x > 0:
-                    rngs += [range(0, x)]
-                if y + 1 < n:
-                    rngs += [range(y + 1, n)]
-                for rng in rngs:
-                    rng = misc.format_range(rng, max=5)
-                    message = tags.safestr('f(x) != {}'.format(rng))
+                    self.tag('unusual-unused-plural-forms', plural_forms, '=>', plural_forms_hint)
+            elif len(locally_correct_plural_forms) == 1:
+                [[locally_correct_n, locally_correct_expr]] = locally_correct_plural_forms
+        plural_preimage = collections.defaultdict(list)
+        unusual_plural_forms = False
+        codomain_limit = 200
+        try:
+            for i in range(codomain_limit):
+                fi = expr(i)
+                if fi >= n:
+                    message = tags.safe_format('f({}) = {} >= {}'.format(i, fi, n))
                     if has_plurals:
                         self.tag('codomain-error-in-plural-forms', message)
                     else:
                         self.tag('codomain-error-in-unused-plural-forms', message)
+                    break
+                plural_preimage[fi] += [i]
+                if (n == locally_correct_n) and (fi != locally_correct_expr(i)) and (not unusual_plural_forms):
+                    if has_plurals:
+                        self.tag('unusual-plural-forms', plural_forms, '=>', plural_forms_hint)
+                    else:
+                        self.tag('unusual-unused-plural-forms', plural_forms, '=>', plural_forms_hint)
+                    unusual_plural_forms = True
+            else:
+                ctx.plural_preimage = dict(plural_preimage)
+        except OverflowError:
+            message = tags.safe_format('f({}): integer overflow', i)
+            if has_plurals:
+                self.tag('arithmetic-error-in-plural-forms', message)
+            else:
+                self.tag('arithmetic-error-in-unused-plural-forms', message)
+        except ZeroDivisionError:
+            message = tags.safe_format('f({}): division by zero', i)
+            if has_plurals:
+                self.tag('arithmetic-error-in-plural-forms', message)
+            else:
+                self.tag('arithmetic-error-in-unused-plural-forms', message)
+        codomain = expr.codomain()
+        if codomain is not None:
+            (x, y) = codomain
+            uncov_rngs = []
+            if x > 0:
+                uncov_rngs += [range(0, x)]
+            if y + 1 < n:
+                uncov_rngs += [range(y + 1, n)]
+        if (not uncov_rngs) and (ctx.plural_preimage is not None):
+            period = expr.period()
+            if period is None:
+                period = (0, 1e999)
+            if sum(period) < codomain_limit:
+                for i in sorted(ctx.plural_preimage):
+                    if (i > 0) and (i - 1 not in ctx.plural_preimage):
+                        uncov_rngs += [range(i - 1, i)]
+                        break
+                    if (i + 1 < n) and (i + 1 not in ctx.plural_preimage):
+                        uncov_rngs += [range(i + 1, i + 2)]
+                        break
+        for rng in uncov_rngs:
+            rng = misc.format_range(rng, max=5)
+            message = tags.safestr('f(x) != {}'.format(rng))
+            if has_plurals:
+                self.tag('codomain-error-in-plural-forms', message)
+            else:
+                self.tag('codomain-error-in-unused-plural-forms', message)
+            ctx.plural_preimage = None
 
     @checks_header_fields('MIME-Version', 'Content-Transfer-Encoding', 'Content-Type')
     def check_mime(self, ctx):
