@@ -25,7 +25,6 @@ command-line interface
 import argparse
 import io
 import os
-import shutil
 import subprocess as ipc
 import sys
 import tempfile
@@ -37,7 +36,7 @@ from lib import paths
 from lib import tags
 from lib import terminal
 
-__version__ = '0.19'
+__version__ = '0.23'
 
 def initialize_terminal():
     if sys.stdout.isatty():
@@ -82,10 +81,9 @@ def check_deb(filename, *, options):
         binary = False
     else:
         raise UnsupportedFileType
-    tmpdir = tempfile.mkdtemp(prefix='i18nspector.deb.')
     ignore_tags = set(options.ignore_tags)
     ignore_tags.add('unknown-file-type')
-    try:
+    with tempfile.TemporaryDirectory(prefix='i18nspector.deb.') as tmpdir:
         if binary:
             ipc.check_call(['dpkg-deb', '-x', filename, tmpdir])
             real_root = os.path.join(tmpdir, '')
@@ -107,8 +105,6 @@ def check_deb(filename, *, options):
                     continue
                 if os.path.isfile(path):
                     check_file(path, options=options)
-    finally:
-        shutil.rmtree(tmpdir)
 
 def check_all(files, *, options):
     for filename in files:
@@ -125,7 +121,7 @@ def main():
     initialize_terminal()
     ap = argparse.ArgumentParser(description=__doc__)
     ap.add_argument('--version', action='version', version='%(prog)s {}'.format(__version__))
-    ap.add_argument('-l', '--language', metavar='<lang>', help='assume this langauge')
+    ap.add_argument('-l', '--language', metavar='<lang>', help='assume this language')
     ap.add_argument('--unpack-deb', action='store_true', help='allow unpacking Debian packages')
     ap.add_argument('--file-type', metavar='<file-type>', help=argparse.SUPPRESS)
     ap.add_argument('--traceback', action='store_true', help=argparse.SUPPRESS)
