@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -32,14 +32,14 @@ import itertools
 import os
 import unicodedata
 
-from . import iconv
-from . import misc
-from . import paths
+from lib import iconv
+from lib import misc
+from lib import paths
 
 class EncodingLookupError(LookupError):
 
     def __init__(self, encoding):
-        return LookupError.__init__(self, 'unknown encoding: ' + encoding)
+        LookupError.__init__(self, 'unknown encoding: ' + encoding)
 
 def _not_implemented(*args, **kwargs):
     raise NotImplementedError
@@ -230,4 +230,4 @@ def get_character_name(ch):
             raise
         return 'control character ' + name
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
