@@ -1,4 +1,4 @@
-# Copyright © 2012-2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2016 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -19,10 +19,147 @@
 # SOFTWARE.
 
 '''
-squeeze Python abstract syntax trees into C integer expressions semantics
+C integer expressions
 '''
 
 import ast
+import contextlib
+import functools
+import tempfile
+
+import rply
+import rply.errors
+
+LexingError = rply.errors.LexingError
+ParsingError = rply.errors.ParsingError
+
+# http://git.savannah.gnu.org/cgit/gettext.git/tree/gettext-runtime/intl/plural.y?id=v0.18.3#n132
+
+@functools.lru_cache(maxsize=None)
+def create_lexer():
+    lg = rply.LexerGenerator()
+    lg.add('IF', r'[?]')
+    lg.add('ELSE', r':')
+    lg.add('OR', r'[|][|]')
+    lg.add('AND', r'[&][&]')
+    lg.add('EQ', r'[!=]=')
+    lg.add('CMP', r'[<>]=?')
+    lg.add('ADDSUB', r'[+-]')
+    lg.add('MULDIV', r'[*/%]')
+    lg.add('NOT', r'!')
+    lg.add('LPAR', r'[(]')
+    lg.add('RPAR', r'[)]')
+    lg.add('VAR', r'n')
+    lg.add('INT', r'[0-9]+')
+    lg.ignore(r'[ \t]+')
+    return lg.build()
+
+@contextlib.contextmanager
+def _throwaway_tempdir():
+    # mitigation for RPLY's insecure use of /tmp:
+    # CVE-2014-1604, CVE-2014-1938
+    with tempfile.TemporaryDirectory(prefix='i18nspector.rply.') as new_tempdir:
+        original_tempdir = tempfile.tempdir
+        try:
+            tempfile.tempdir = new_tempdir
+            yield
+        finally:
+            tempfile.tempdir = original_tempdir
+
+@functools.lru_cache(maxsize=None)
+def create_parser(lexer):
+    pg = rply.ParserGenerator(
+        [rule.name for rule in lexer.rules],
+        precedence=[
+            ('right', ['IF', 'ELSE']),
+            ('left', ['OR']),
+            ('left', ['AND']),
+            ('left', ['EQ']),
+            ('left', ['CMP']),
+            ('left', ['ADDSUB']),
+            ('left', ['MULDIV']),
+            ('right', ['NOT']),
+        ],
+        cache_id='i18nspector-intexpr',
+    )
+    ast_bool = {
+        '&&': ast.And(),
+        '||': ast.Or(),
+    }
+    ast_cmp = {
+        '==': ast.Eq(),
+        '!=': ast.NotEq(),
+        '<': ast.Lt(),
+        '<=': ast.LtE(),
+        '>': ast.Gt(),
+        '>=': ast.GtE(),
+    }
+    ast_arithmetic = {
+        '+': ast.Add(),
+        '-': ast.Sub(),
+        '*': ast.Mult(),
+        '/': ast.Div(),
+        '%': ast.Mod(),
+    }
+    ast_not = ast.Not()
+    @pg.production('start : exp')
+    def eval_start(p):
+        [exp] = p
+        return ast.Expr(exp)
+    @pg.production('exp : exp IF exp ELSE exp')
+    def expr_ifelse(p):
+        [cond, _, body, _, orelse] = p
+        return ast.IfExp(cond, body, orelse)
+    @pg.production('exp : exp OR exp')
+    @pg.production('exp : exp AND exp')
+    def expr_bool(p):
+        [left, tok, right] = p
+        op = ast_bool[tok.getstr()]
+        return ast.BoolOp(op, [left, right])
+    @pg.production('exp : exp EQ exp')
+    @pg.production('exp : exp CMP exp')
+    def expr_cmp(p):
+        [left, tok, right] = p
+        op = ast_cmp[tok.getstr()]
+        return ast.Compare(left, [op], [right])
+    @pg.production('exp : exp ADDSUB exp')
+    @pg.production('exp : exp MULDIV exp')
+    def expr_arithmetic(p):
+        [left, tok, right] = p
+        op = ast_arithmetic[tok.getstr()]
+        return ast.BinOp(left, op, right)
+    @pg.production('exp : NOT exp')
+    def expr_not(p):
+        [_, value] = p
+        return ast.UnaryOp(ast_not, value)
+    @pg.production('exp : LPAR exp RPAR')
+    def expr_par(p):
+        [_, exp, _] = p
+        return exp
+    @pg.production('exp : VAR')
+    def expr_var(p):
+        [tok] = p
+        ident = tok.getstr()
+        assert ident == 'n'
+        return ast.Name(ident, ast.Load())
+    @pg.production('exp : INT')
+    def expr_int(p):
+        [tok] = p
+        n = int(tok.getstr())
+        return ast.Num(n)
+    with _throwaway_tempdir():
+        return pg.build()
+
+class Parser(object):
+
+    def __init__(self):
+        self._lexer = create_lexer()
+        self._parser = create_parser(self._lexer)
+
+    def parse(self, s):
+        tokens = self._lexer.lex(s)
+        node = self._parser.parse(tokens)
+        return Expression(node)
 
 from lib import misc
 
@@ -73,34 +210,19 @@ class BaseEvaluator(object):
     # ====================
 
     def _visit_compare(self, node):
-        # This one is tricky because in C equality comparison operators have
-        # lower priority that inequality comparison operators. This is unlike
-        # Python, in which they have the same priority.
         assert len(node.comparators) == len(node.ops)
-        new_vals = []
-        new_ops = []
-        # high priority: <, <=, >, >=
-        left = self._visit(node.left)
+        if len(node.ops) != 1:
+            raise NotImplementedError
+        left = node.left
+        [op] = node.ops
+        [right] = node.comparators
+        left = self._visit(left)
         if left is None:
             return
-        for op, right in zip(node.ops, node.comparators):
-            right = self._visit(right)
-            if right is None:
-                return
-            if isinstance(op, (ast.Eq, ast.NotEq)):
-                new_vals += [left]
-                new_ops += [op]
-                left = right
-            else:
-                left = self._visit(op, left, right)
-        new_vals += [left]
-        assert len(new_vals) == len(new_ops) + 1
-        # low priority: ==, !=
-        new_vals = iter(new_vals)
-        left = next(new_vals)
-        for op, right in zip(new_ops, new_vals):
-            left = self._visit(op, left, right)
-        return left
+        right = self._visit(right)
+        if right is None:
+            return
+        return self._visit(op, left, right)
 
     # boolean operators
     # =================
@@ -143,7 +265,7 @@ class Evaluator(BaseEvaluator):
     # unary operators
     # ===============
 
-    def _visit_invert(self, node, x):
+    def _visit_not(self, node, x):
         return int(not x)
 
     # comparison operators
@@ -192,8 +314,8 @@ class Evaluator(BaseEvaluator):
         else:
             return self._visit(node.orelse)
 
-    # contants, variables
-    # ===================
+    # constants, variables
+    # ====================
 
     def _visit_num(self, node):
         return self._check_overflow(node.n)
@@ -209,22 +331,6 @@ class CodomainEvaluator(BaseEvaluator):
         self._ctxt = context
         self._node = node
 
-    def __call__(self):
-        node = self._node
-        assert isinstance(node, ast.Expr)
-        return self._visit_expr(node)
-
-    def _visit(self, node, *args):
-        try:
-            fn = getattr(self, '_visit_' + type(node).__name__.lower())
-        except KeyError:  # <no-coverage>
-            raise NotImplementedError(type(node).__name__)
-        return fn(node, *args)
-
-    def _visit_expr(self, node):
-        [node] = ast.iter_child_nodes(node)
-        return self._visit(node)
-
     # binary operators
     # ================
 
@@ -278,7 +384,7 @@ class CodomainEvaluator(BaseEvaluator):
     # unary operators
     # ===============
 
-    def _visit_invert(self, node, x):
+    def _visit_not(self, node, x):
         if x[0] > 0:
             return (0, 0)
         elif x == (0, 0):
@@ -399,8 +505,8 @@ class CodomainEvaluator(BaseEvaluator):
             max(x[1], y[1]),
         )
 
-    # contants, variables
-    # ===================
+    # constants, variables
+    # ====================
 
     def _visit_num(self, node):
         n = node.n
@@ -411,13 +517,168 @@ class CodomainEvaluator(BaseEvaluator):
     def _visit_name(self, node):
         return (0, self._ctxt.max - 1)
 
+def gcd(x, y):
+    while y:
+        (x, y) = (y, x % y)
+    return x
+
+def lcm(x, *ys):
+    r = x
+    for y in ys:
+        r //= gcd(r, y)
+        r *= y
+    return r
+
+class PeriodEvaluator(BaseEvaluator):
+
+    def __init__(self, node, *, bits):
+        context = misc.Namespace()
+        context.max = 1 << bits
+        self._ctxt = context
+        self._node = node
+
+    # binary operators
+    # ================
+
+    def _visit_binop(self, node):
+        const_mod = (
+            isinstance(node.op, ast.Mod) and
+            isinstance(node.left, ast.Name) and
+            isinstance(node.right, ast.Num)
+        )
+        if const_mod:
+            n = node.right.n
+            if (n <= 0) or (n >= self._ctxt.max):
+                return
+            return (0, n)
+        x = self._visit(node.left)
+        if x is None:
+            return
+        y = self._visit(node.right)
+        if y is None:
+            return
+        (xo, xp) = x
+        (yo, yp) = y
+        ro = max(xo, yo)
+        rp = lcm(xp, yp)
+        if rp >= self._ctxt.max:
+            return
+        else:
+            return (ro, rp)
+
+    # unary operators
+    # ===============
+
+    def _visit_unaryop(self, node):
+        return self._visit(node.operand)
+
+    # comparison operators
+    # ====================
+
+    def _visit_compare(self, node):
+        assert len(node.comparators) == len(node.ops)
+        if len(node.ops) != 1:
+            raise NotImplementedError
+        [op] = node.ops
+        [right] = node.comparators
+        const_cmp = (
+            isinstance(node.left, ast.Name) and
+            isinstance(right, ast.Num)
+        )
+        if const_cmp:
+            n = right.n
+            if (n < 0) or (n >= self._ctxt.max):
+                return
+            # (n <cmp> N) is constant starting with either N or N+1,
+            # depending on <cmp>:
+            #
+            #        …N-1  N  N+1 N+2…
+            # -------+---+---+---+----
+            # n != N | 1 . 0 . 1 . 1
+            # n == N | 0 . 1 . 0 . 0
+            # n <= N | 1 . 1 . 0 . 0
+            # n >  N | 0 . 0 . 1 . 1
+            # -------+---+---+---+----
+            # n <  N | 1 . 0 . 0 . 0
+            # n >= N | 0 . 1 . 1 . 1
+            # -------+---+---+---+----
+            if isinstance(op, (ast.Lt, ast.GtE)):
+                return (n, 1)
+            else:
+                if n + 1 == self._ctxt.max:
+                    return
+                return (n + 1, 1)
+        x = self._visit(node.left)
+        if x is None:
+            return
+        y = self._visit(right)
+        if y is None:
+            return
+        (xo, xp) = x
+        (yo, yp) = y
+        ro = max(xo, yo)
+        rp = lcm(xp, yp)
+        if rp >= self._ctxt.max:
+            return
+        else:
+            return (ro, rp)
+
+    # boolean operators
+    # =================
+
+    def _visit_boolop(self, node):
+        (xo, xp) = (0, 1)
+        for arg in node.values:
+            y = self._visit(arg)
+            if y is None:
+                return
+            (yo, yp) = y
+            xo = max(xo, yo)
+            xp = lcm(xp, yp)
+            if xp >= self._ctxt.max:
+                return
+        return (xo, xp)
+
+    # if-then-else expression
+    # =======================
+
+    def _visit_ifexp(self, node):
+        test = self._visit(node.test)
+        if test is None:
+            return
+        (to, tp) = test
+        x = self._visit(node.body)
+        if x is None:
+            return
+        (xo, xp) = x
+        y = self._visit(node.orelse)
+        if y is None:
+            return
+        (yo, yp) = y
+        ro = max(to, xo, yo)
+        rp = lcm(tp, xp, yp)
+        if rp >= self._ctxt.max:
+            return
+        else:
+            return (ro, rp)
+
+    # constants, variables
+    # ====================
+
+    def _visit_num(self, node):
+        n = node.n
+        if n < 0 or n >= self._ctxt.max:
+            return
+        return (0, 1)
+
+    def _visit_name(self, node):
+        return
+
 class Expression(object):
 
-    def __init__(self, s):
-        module = ast.parse('({})'.format(s), filename='<intexpr>')
-        assert isinstance(module, ast.Module)
-        [node] = ast.iter_child_nodes(module)
-        assert isinstance(node, ast.Expr)
+    def __init__(self, node):
+        if not isinstance(node, ast.Expr):
+            raise TypeError  # <no-coverage>
         self._node = node
 
     def __call__(self, n, *, bits=32):
@@ -430,10 +691,19 @@ class Expression(object):
     def codomain(self, *, bits=32):
         '''
         return
-        * (i, j) such that for every n, f(n) ∈ {i, i+1, …, j}
+        * (L, R) such that for every n: L ≤ f(n) ≤ R
         * or None
         '''
         e = CodomainEvaluator(self._node, bits=bits)
         return e()
 
+    def period(self, *, bits=32):
+        '''
+        return
+        * (O, P) such that for every n ≥ O: f(n + P) = f(n)
+        * or None
+        '''
+        e = PeriodEvaluator(self._node, bits=bits)
+        return e()
+
 # vim:ts=4 sts=4 sw=4 et
