@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -27,8 +27,8 @@ import os
 import re
 import unicodedata
 
-from . import misc
-from . import paths
+from lib import misc
+from lib import paths
 
 def _munch_language_name(s):
     # Normalize whitespace:
@@ -167,14 +167,14 @@ class Language(object):
             # overhead per encode() call. To reduce number of such calls,
             # optimize the common case of all characters being representable.
             ''.join(characters).encode(encoding)
-        except UnicodeError:
+        except UnicodeEncodeError:
             pass
         else:
             return result
         for character in characters:
             try:
                 character.encode(encoding)
-            except UnicodeError as exc:
+            except UnicodeEncodeError as exc:
                 result += [character]
                 if exc.reason.startswith('iconv:'):
                     # Avoid further calls to iconv(1):
@@ -197,6 +197,9 @@ class Language(object):
             s += '@' + self.modifier
         return s
 
+    def __repr__(self):
+        return '<Language {}>'.format(self)
+
 def _read_iso_codes():
     # ISO language/territory codes:
     path = os.path.join(paths.datadir, 'iso-codes')
@@ -281,7 +284,8 @@ def get_language_for_name(name):
         for subname in _name.split(','):
             subname = subname.strip()
             result = _name_to_code.get(subname)
-            results.add(result)
+            if result is not None:
+                results.add(result)
         if len(results) == 1:
             return parse(results.pop())
     raise LookupError(name)
@@ -346,4 +350,4 @@ def _get_characters(language, modifier=None, strict=True):
             if not (ch.startswith('(') and ch.endswith(')'))
         ]
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
