@@ -1,4 +1,4 @@
-# Copyright © 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2013-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -33,7 +33,7 @@ import sys
 
 import polib
 
-from . import encodings
+from lib import encodings
 
 little_endian_magic = b'\xDE\x12\x04\x95'
 big_endian_magic = little_endian_magic[::-1]
@@ -176,6 +176,7 @@ class Parser(object):
                 {i: s.decode(encoding) for i, s in enumerate(msgstrs)}
             )
         entry = polib.MOEntry(**kwargs)
+        entry.comment = None
         entry.occurrences = ()
         entry.flags = ()  # https://bitbucket.org/izi/polib/issue/47
         entry.translated = lambda: True
@@ -203,4 +204,4 @@ if __name__ == '__main__':
 else:
     del main
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
