@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -27,9 +27,11 @@ import re
 
 class _dummy_curses:
 
+    @staticmethod
     def tigetstr(*args, **kwargs):
         return b''
 
+    @staticmethod
     def tparm(*args, **kwargs):
         return b''
 
@@ -84,8 +86,15 @@ def initialize():
     try:
         _curses.tparm(b'x')
     except TypeError:
-        # curses.tparm() is broken in early version of Python 3.2:
-        # http://bugs.python.org/issue10570
+        # curses.tparm() is broken in early versions of Python 3.2:
+        # https://bugs.python.org/issue10570
+        _curses = _dummy_curses
+        return
+    try:
+        _curses.tigetstr('x')
+    except TypeError:
+        # curses.tigetstr() is broken in PyPy3:
+        # https://bitbucket.org/pypy/pypy/issue/1997
         _curses = _dummy_curses
         return
     for key, value in vars(_curses).items():
@@ -94,4 +103,4 @@ def initialize():
             getattr(colors, key)
             setattr(colors, key, value)
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
