@@ -89,15 +89,20 @@ def test_tags():
                     added_tag, removed_tag = rename_re.match(line).groups()
                     yield rename, 'rename', removed_tag, added_tag
             else:
-                assert 0
+                assert False
     data_tags = frozenset(tag.name for tag in lib.tags.iter_tags())
     for tag in sorted(changelog_tags | data_tags):
         yield check, 'check', tag
 
 def test_trailing_whitespace():
     path = os.path.join(docdir, 'changelog')
+    unreleased = False
     with open(path, 'rt', encoding='UTF-8') as file:
         for n, line in enumerate(file, 1):
+            if n == 1 and ' UNRELEASED;' in line:
+                unreleased = True
+            if n == 3 and unreleased and line == '  * \n':
+                continue
             line = line.rstrip('\n')
             if line[-1:].isspace():
                 raise AssertionError('trailing whitespace at line {0}'.format(n))
