@@ -1,4 +1,4 @@
-# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2016 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -231,13 +231,13 @@ class test_plural_exp:
         with assert_raises(self.error):
             self.t('2 ? (3 : 7 ? ) : 23')
 
-    def test_unary_plus(self):
+    def test_unary_minus(self):
         with assert_raises(self.error):
             self.t('-37')
         with assert_raises(self.error):
             self.t('23 + (-37)')
 
-    def test_unary_minus(self):
+    def test_unary_plus(self):
         with assert_raises(self.error):
             self.t('+42')
         with assert_raises(self.error):
@@ -285,6 +285,10 @@ class test_plural_exp:
         with assert_raises(self.error):
             self.t('(6, 7)')
 
+    def test_starred(self):
+        with assert_raises(self.error):
+            self.t('*42')
+
     def test_exotic_whitespace(self):
         with assert_raises(self.error):
             self.t('6 *\xA07')
@@ -512,30 +516,134 @@ class test_codomain:
     def test_cond_both_branches_error(self):
         self.t('n ? (n / 0) : (n / 0)', None)
 
-    def test_cond_both_braches_ok(self):
+    def test_cond_both_branches_ok(self):
         self.t('n ? 37 : 42', 37, 42)
         self.t(
             'n ? (6 + n%23) : (7 + n%37)',
             6, 37 + 7 - 1
         )
 
+class test_period:
+
+    def t(self, s, offset, period=None):
+        f = M.parse_plural_expression(s)
+        op = f.period()
+        if offset is None:
+            assert period is None
+            assert_is_none(op)
+        else:
+            assert_equal(op, (offset, period))
+
+    def test_num(self):
+        self.t('42', 0, 1)
+
+    def test_const_mod(self):
+        self.t('n % 42', 0, 42)
+        self.t('n % 0', None)
+
+    def test_binop(self):
+        self.t('n + (n % 37)', None)
+        self.t('(n % 37) + n', None)
+        self.t('(n % 6) + (n % 14)', 0, 42)
+        self.t('(n % 641) * (n % 6700417)', None)  # overflow
+
+    def test_unaryop(self):
+        self.t('!n', None)
+        self.t('!(n % 37)', 0, 37)
+
+    def _cmp_shift(self, op):
+        def e(n, op, m):
+            return eval(str(n) + op + str(m))
+        return e(0, op, 0) != e(1, op, 0)
+
+    def test_const_cmp(self):
+        for op in {'!=', '==', '<', '<=', '>', '>='}:
+            shift = self._cmp_shift(op)
+            self.t('n {op} {i}'.format(op=op, i=37), 37 + shift, 1)
+
+    def test_const_cmp_overflow(self):
+        ops = {'!=', '==', '<', '<=', '>', '>='}
+        m = (1 << 32) - 1
+        for op in ops:
+            shift = self._cmp_shift(op)
+            self.t('n {op} {m}'.format(op=op, m=(m - 1)), m - 1 + shift, 1)
+            if shift:
+                self.t('n {op} {m}'.format(op=op, m=m), None)
+            else:
+                self.t('n {op} {m}'.format(op=op, m=m), m, 1)
+            self.t('n {op} {m}'.format(op=op, m=(m + 1)), None)
+            self.t('n {op} {m}'.format(op=op, m=(m + 42)), None)
+
+    def test_compare(self):
+        self.t('n < (n % 37)', None)
+        self.t('(n % 37) < n', None)
+        self.t('(n % 6) < (n % 14)', 0, 42)
+        self.t('(n % 641) < (n % 6700417)', None)  # overflow
+
+    def test_boolop(self):
+        self.t('n && (n % 37)', None)
+        self.t('(n % 37) && n', None)
+        self.t('(n % 6) && (n % 14)', 0, 42)
+        self.t('(n % 641) && (n % 6700417)', None)  # overflow
+
+    def test_ifexp(self):
+        self.t('n ? (n % 3) : (n % 7)', None)
+        self.t('(n % 2) ? n : (n % 7)', None)
+        self.t('(n % 2) ? (n % 3) : n', None)
+        self.t('(n % 2) ? (n % 3) : (n % 7)', 0, 42)
+        self.t('(n % 2) ? (n % 3) : (n % 715827883)', None)  # overflow
+
+    def test_num_overflow(self):
+        m = (1 << 32) - 1
+        self.t(str(m), 0, 1)
+        self.t(str(m + 1), None)
+        self.t(str(m + 42), None)
+
+    def test_real_world(self):
+        self.t('0', 0, 1)
+        self.t('n != 1', 2, 1)
+        self.t('n > 1', 2, 1)
+        self.t('n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3', 0, 100)
+        self.t('n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2', 1, 100)
+        self.t('n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2', 0, 100)
+        self.t('n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2', 0, 100)
+        self.t('n==1 ? 0 : (n==0 || (n%100 > 0 && n%100 < 20)) ? 1 : 2', 2, 100)
+        self.t('n==1 ? 0 : (n>=2 && n<=4) ? 1 : 2', 5, 1)
+        self.t('n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2', 2, 100)
+        self.t('n==1 ? 0 : n==2 ? 1 : 2', 3, 1)
+        self.t('n==1 ? 3 : n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2', 2, 100)
+
 class test_plural_forms:
 
     error = M.PluralFormsSyntaxError
 
-    def t(self, s):
-        return M.parse_plural_forms(s)
+    def t(self, s, *, n, ljunk='', rjunk=''):
+        if ljunk or rjunk:
+            with assert_raises(self.error):
+                 M.parse_plural_forms(s)
+        else:
+            (n0, expr0) = M.parse_plural_forms(s)
+            assert_equal(n0, n)
+        (n1, expr1, ljunk1, rjunk1) = M.parse_plural_forms(s, strict=False)
+        assert_equal(n1, n)
+        assert_equal(ljunk1, ljunk)
+        assert_equal(rjunk1, rjunk)
 
     def test_nplurals_0(self):
         with assert_raises(self.error):
-            self.t('nplurals=0; plural=0;')
+            self.t('nplurals=0; plural=0;', n=0)
 
     def test_nplurals_positive(self):
-        for i in 1, 2, 10, 42:
-            self.t('nplurals={}; plural=0;'.format(i))
+        for n in 1, 2, 10, 42:
+            self.t('nplurals={}; plural=0;'.format(n), n=n)
 
     def test_missing_trailing_semicolon(self):
-        self.t('nplurals=1; plural=0')
+        self.t('nplurals=1; plural=0', n=1)
+
+    def test_junk(self):
+        self.t('eggsnplurals=1; plural=0;', n=1, ljunk='eggs')
+        self.t('nplurals=1; plural=0;ham', n=1, rjunk='ham')
+        self.t('baconnplurals=1; plural=0;spam', n=1, ljunk='bacon', rjunk='spam')
 
 class test_fix_date_format:
 
@@ -590,7 +698,7 @@ class test_fix_date_format:
             '2001-06-25 18:55+0200',
         )
 
-    def test_t_seperator(self):
+    def test_t_separator(self):
         self.t(
             '2003-04-01T09:08+0500',
             '2003-04-01 09:08+0500',
