@@ -32,7 +32,7 @@ from nose.tools import (
     assert_true,
 )
 
-from . import aux
+from . import tools
 
 import lib.encodings
 import lib.ling
@@ -401,7 +401,7 @@ class test_unrepresentable_characters:
         result = lang.get_unrepresentable_characters('ISO-8859-1')
         assert_is_none(result)
 
-    @aux.fork_isolation
+    @tools.fork_isolation
     def test_extra_encoding(self):
         encoding = 'GEORGIAN-PS'
         lang = L.parse_language('pl')
@@ -411,10 +411,35 @@ class test_unrepresentable_characters:
         result = lang.get_unrepresentable_characters(encoding)
         assert_not_equal(result, [])
 
+def test_glibc_supported():
+    def t(l):
+        lang = L.parse_language(l)
+        try:
+            lang.fix_codes()
+        except L.FixingLanguageCodesFailed:
+            # FIXME: some ISO-639-3 codes are not recognized yet
+            if len(l.split('_')[0]) == 3:
+                raise nose.SkipTest('expected failure')
+            raise
+        assert_equal(str(lang), l)
+    try:
+        file = open('/usr/share/i18n/SUPPORTED', encoding='ASCII')
+    except OSError as exc:
+        raise nose.SkipTest(exc)
+    with file:
+        for line in file:
+            if line[:1] in {'#', '\n'}:
+                continue
+            locale, *rest = line.split()
+            if (locale + '.').startswith('iw_IL.'):
+                # iw_IL is obsolete
+                continue
+            yield t, locale
+
 def test_poedit():
     # https://github.com/vslavik/poedit/blob/v1.8.1-oss/src/language_impl_legacy.h
     # There won't be any new names in this table,
-    # so it's safe to harcode them all here.
+    # so it's safe to hardcode them all here.
     def t(name, poedit_ll):
         poedit_ll = L.parse_language(poedit_ll)
         ll = L.get_language_for_name(name)
