@@ -80,7 +80,7 @@ def test_add_argument():
 
 def test_text():
     fmt = M.FormatString('eggs%dbacon%dspam')
-    assert_equal(len(fmt), (5))
+    assert_equal(len(fmt), 5)
     fmt = list(fmt)
     assert_equal(fmt[0], 'eggs')
     assert_equal(fmt[2], 'bacon')
@@ -273,8 +273,7 @@ class test_redundant_flag:
     def test_plus_space(self):
         self.t('%+ d')
 
-    def test_zero_prec(self):
-        self.t('%0.17d')
+    # TODO: Check for other redundant flags, for example “%+s”.
 
 class test_expected_flag:
 
@@ -551,4 +550,4 @@ class test_get_last_integer_conversion:
         self.t('%1$*2$d%3$d', 2, None)
         self.t('%1$*3$d%2$d', 2, None)
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
